********************
API Reference
********************

Oct2Py
======
.. automodule:: oct2py.session
   :members: Oct2Py

Oct2PyError
===========
.. automodule:: oct2py.utils
   :members: Oct2PyError
   
get_log
=======
.. automodule:: oct2py.utils
   :members: get_log
   
Struct
=======
.. automodule:: oct2py.utils
   :members: Struct
